#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-plugin-api
version:              2.3.0.0
visibility:           public
id:                   hls-plugin-api-2.3.0.0-FlTTTMUPuF0DZZPvKdhYpj
key:                  hls-plugin-api-2.3.0.0-FlTTTMUPuF0DZZPvKdhYpj
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Haskell Language Server API for plugin communication
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  8a33202d868d1749733303a72ba01940
exposed:              True
exposed-modules:
    Ide.Logger Ide.Plugin.Config Ide.Plugin.ConfigUtils
    Ide.Plugin.Error Ide.Plugin.Properties Ide.Plugin.RangeMap
    Ide.Plugin.Resolve Ide.PluginUtils Ide.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-plugin-api-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-plugin-api-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-plugin-api-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-plugin-api
hs-libraries:         HShls-plugin-api-2.3.0.0-FlTTTMUPuF0DZZPvKdhYpj
depends:
    Diff-0.5-KEZ9YIzWdyM3F5SFakDIw6
    aeson-2.2.2.0-Bvq1RZLTB982HJyF7e96XU base-4.18.2.1
    co-log-core-0.3.2.6-39Wv1c0c3NEAmuSWUqUwqo containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    dependent-map-0.4.0.1-3gAkNvjrVmy3M73pf6MCP7
    dependent-sum-0.7.2.0-EAyOcQhSpuQ8ukUO3cyqz4
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    extra-1.7.16-EBdVSHGIn1MFifI9eiYLtn filepath-1.4.300.1 ghc-9.6.6
    hashable-1.4.7.0-LB47rq9amzm4H74gyqVlYy
    hls-graph-2.3.0.0-COV5jQws3mZ7W8vUwofT07
    hw-fingertree-0.1.2.1-Hr5Ziks2LJdFKP7RJuX3nf
    lens-5.3.4-4VhpdbpDp0x9CLN9dxQmc7
    lens-aeson-1.2.3-FqT8XoTlMtx6waVVY3vUkT
    lsp-2.2.0.0-BBA8C8ebAHoAYQmS8hf6TA
    megaparsec-9.7.0-IhFYCfUpu092G9CaEkXpKA mtl-2.3.1
    opentelemetry-0.8.0-9OcmEusDY8yBh6FDdmq8gP
    optparse-applicative-0.18.1.0-7oEyKoVs7Vv7h3tuBTvFI7
    prettyprinter-1.7.1-3tqZuvkzaQgKArc0IOnBsn
    regex-tdfa-1.3.2.5-DSpNPpF3mjD6KIMmBJHiEZ
    row-types-1.0.1.2-EpdWJYAHg7XKOZxhFScaQ6 stm-2.5.1.0 text-2.0.2
    time-1.12.2 transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-Jl71xZxtWw8GvgwO5TEzPz
    unordered-containers-0.2.20.1-ITIVaOGw28dDFkmcPJu0s3

haddock-interfaces:
    /usr/share/doc/haskell-hls-plugin-api/html/hls-plugin-api.haddock

haddock-html:         /usr/share/doc/haskell-hls-plugin-api/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

